------

.. class:: footer

    Copyright © 2005–2017, Marius Gedminas.  This page should be
    `valid <https://validator.w3.org/nu/?doc=https://gtimelog.org/>`__
    HTML and CSS.  It's maintained `on GitHub also
    <https://github.com/gtimelog/gtimelog.org>`__.
